@@ -24,7 +24,7 @@ BasicFileLauncher::~BasicFileLauncher() {
 }
 
 bool BasicFileLauncher::launchFiles(const FileInfoList& fileInfos, GAppLaunchContext* ctx) {
-    std::unordered_map<std::string, FileInfoList> mimeTypeToFiles;
+    FileInfoList mimeTypeInfos;
     FileInfoList folderInfos;
     FilePathList pathsToLaunch;
     // classify files according to different mimetypes
@@ -72,8 +72,7 @@ bool BasicFileLauncher::launchFiles(const FileInfoList& fileInfos, GAppLaunchCon
             folderInfos.emplace_back(fileInfo);
         }
         else {
-            auto& mimeType = fileInfo->mimeType();
-            mimeTypeToFiles[mimeType->name()].emplace_back(fileInfo);
+            mimeTypeInfos.emplace_back(fileInfo);
         }
     }
 
@@ -83,19 +82,62 @@ bool BasicFileLauncher::launchFiles(const FileInfoList& fileInfos, GAppLaunchCon
         openFolder(ctx, folderInfos, err);
     }
 
-    // open files of different mime-types with their default app
-    for(auto& typeFiles : mimeTypeToFiles) {
-        auto& mimeType = typeFiles.first;
-        auto& files = typeFiles.second;
-        GErrorPtr err;
-        GAppInfoPtr app{g_app_info_get_default_for_type(mimeType.c_str(), false), false};
-        if(!app) {
-            app = chooseApp(files, mimeType.c_str(), err);
+    // Open files of different mime-types with their default apps,
+    // grouping them together appropriately and respecting their order.
+    std::vector<std::pair<GAppInfoPtr, FileInfoList>> launches;
+    std::unordered_map<std::string, GAppInfoPtr> defaultApps;
+    for(const auto& file : mimeTypeInfos) {
+        const char* mimeTypeName = file->mimeType()->name();
+        auto it = defaultApps.find(mimeTypeName);
+        if(it == defaultApps.end()) {
+            GErrorPtr err;
+            GAppInfoPtr app{g_app_info_get_default_for_type(mimeTypeName, false), false};
+            if(!app) {
+                app = chooseApp(FileInfoList(), mimeTypeName, err);
+            }
+            if(app) {
+                // check whether this app is already found for another mimetype
+                bool alreadyFound = false;
+                for(auto& launch : launches) {
+                    if(g_app_info_equal(app.get(), launch.first.get())) {
+                        alreadyFound = true;
+                        // remember it as the default app for this mimetype
+                        defaultApps[mimeTypeName] = launch.first;
+                        // update this launch (add the file to it)
+                        auto tmp = launch.second;
+                        tmp.push_back(file);
+                        launch.second = tmp;
+                        break;
+                    }
+                }
+                if(!alreadyFound) {
+                    defaultApps[mimeTypeName] = app;
+                    // remember this launch
+                    FileInfoList files;
+                    files.push_back(file);
+                    launches.push_back(std::make_pair(app, files));
+                }
+            }
+            else {
+                // remember that this mimetype has no default app (don't ask again)
+                defaultApps[mimeTypeName] = nullptr;
+            }
         }
-        if(app) {
-            launchWithApp(app.get(), files.paths(), ctx);
+        else if(auto app = it->second) { // a default app was found/chosen before
+            for(auto& launch : launches) {
+                if(launch.first == app) {
+                    auto tmp = launch.second;
+                    tmp.push_back(file);
+                    launch.second = tmp;
+                    break;
+                }
+            }
         }
     }
+    // perform the launches
+    for(const auto& launch : launches) {
+        launchWithApp(launch.first.get(), launch.second.paths(), ctx);
+    }
 
     if(!pathsToLaunch.empty()) {
         launchPaths(pathsToLaunch, ctx);
@@ -267,7 +309,7 @@ bool BasicFileLauncher::launchDesktopEntry(const char *desktopEntryName, const F
         }
         uris = g_list_reverse(uris);
         GErrorPtr err;
-        ret = bool(fm_app_info_launch(app, uris, ctx, &err));
+        ret = bool(fm_app_info_launch_uris(app, uris, ctx, &err));
         g_list_free_full(uris, g_free);
         if(!ret) {
             // FIXME: show error for all files
