@@ -14,7 +14,8 @@ namespace Fm {
 QThreadPool* ThumbnailJob::threadPool_ = nullptr;
 
 bool ThumbnailJob::localFilesOnly_ = true;
-int ThumbnailJob::maxThumbnailFileSize_ = 0;
+int ThumbnailJob::maxThumbnailFileSize_ = 4096; // in KiB
+int ThumbnailJob::maxExternalThumbnailFileSize_ = -1;
 
 ThumbnailJob::ThumbnailJob(FileInfoList files, int size):
     files_{std::move(files)},
@@ -39,7 +40,7 @@ void ThumbnailJob::exec() {
 }
 
 QImage ThumbnailJob::readImageFromStream(GInputStream* stream, size_t len) {
-    // FIXME: should we set a limit here? Otherwise if len is too large, we can run out of memory.
+    // The size limit has been set in generateThumbnail().
     std::unique_ptr<unsigned char[]> buffer{new unsigned char[len]}; // allocate enough buffer
     unsigned char* pbuffer = buffer.get();
     size_t totalReadSize = 0;
@@ -136,7 +137,7 @@ bool ThumbnailJob::isThumbnailOutdated(const std::shared_ptr<const FileInfo>& fi
     return (thumb_mtime.isEmpty() || thumb_mtime.toULongLong() != file->mtime());
 }
 
-bool ThumbnailJob::readJpegExif(GInputStream *stream, QImage& thumbnail, QMatrix& matrix) {
+bool ThumbnailJob::readJpegExif(GInputStream *stream, QImage& thumbnail, QTransform& matrix) {
     /* try to extract thumbnails embedded in jpeg files */
     ExifLoader* exif_loader = exif_loader_new();
     while(!isCancelled()) {
@@ -201,11 +202,15 @@ QImage ThumbnailJob::generateThumbnail(const std::shared_ptr<const FileInfo>& fi
     QImage result;
     auto mime_type = file->mimeType();
     if(isSupportedImageType(mime_type)) {
+        if (file->size() > static_cast<uint64_t>(maxThumbnailFileSize_) * 1024) {
+            return result;
+        }
         GFileInputStreamPtr ins{g_file_read(origPath.gfile().get(), cancellable_.get(), nullptr), false};
-        if(!ins)
-            return QImage();
+        if(!ins) {
+            return result;
+        }
         bool fromExif = false;
-        QMatrix matrix;
+        QTransform matrix;
         if(strcmp(mime_type->name(), "image/jpeg") == 0) { // if this is a jpeg file
             // try to get the thumbnail embedded in EXIF data
             if(readJpegExif(G_INPUT_STREAM(ins.get()), result, matrix)) {
@@ -242,6 +247,10 @@ QImage ThumbnailJob::generateThumbnail(const std::shared_ptr<const FileInfo>& fi
         }
     }
     else { // the image format is not supported, try to find an external thumbnailer
+        if (maxExternalThumbnailFileSize_ >= 0
+            && file->size() > static_cast<uint64_t>(maxExternalThumbnailFileSize_) * 1024) {
+            return result;
+        }
         // try all available external thumbnailers for it until sucess
         int target_size = size_ > 128 ? 256 : 128;
         file->mimeType()->forEachThumbnailer([&](const std::shared_ptr<const Thumbnailer>& thumbnailer) {
@@ -288,11 +297,18 @@ void ThumbnailJob::setLocalFilesOnly(bool value) {
 }
 
 void ThumbnailJob::setMaxThumbnailFileSize(int size) {
-    maxThumbnailFileSize_ = size;
+    maxThumbnailFileSize_ = qMax(size, 0);
     if(fm_config) {
         fm_config->thumbnail_max = maxThumbnailFileSize_;
     }
 }
 
+void ThumbnailJob::setMaxExternalThumbnailFileSize(int size) {
+    maxExternalThumbnailFileSize_ = size;
+    if(fm_config) {
+        fm_config->external_thumbnail_max = maxExternalThumbnailFileSize_;
+    }
+}
+
 
 } // namespace Fm
