@@ -51,7 +51,7 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     connect(ui->sidePane, &SidePane::hiddenPlaceSet, this, &FileDialog::onSettingHiddenPlace);
 
     // folder view
-    proxyModel_ = new ProxyFolderModel(this);
+    proxyModel_ = new ProxyFolderModel();
     proxyModel_->sort(FolderModel::ColumnFileName, Qt::AscendingOrder);
     proxyModel_->setThumbnailSize(64);
     proxyModel_->setShowThumbnails(true);
@@ -247,6 +247,10 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
 
 FileDialog::~FileDialog() {
     freeFolder();
+    delete proxyModel_;
+    if(folderModel_) {
+        folderModel_->unref();
+    }
 }
 
 bool FileDialog::eventFilter(QObject* watched, QEvent* event) {
@@ -486,7 +490,11 @@ QString FileDialog::suffix(bool checkDefaultSuffix) const {
             auto right = currentNameFilter_.indexOf(QLatin1Char(')'), left);
             if(right != -1) {
                 QString nameFilter = currentNameFilter_.mid(left, right - left);
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+                QString suffix = nameFilter.simplified().split(QLatin1Char(' '), Qt::SkipEmptyParts).at(0);
+#else
                 QString suffix = nameFilter.simplified().split(QLatin1Char(' '), QString::SkipEmptyParts).at(0);
+#endif
                 left = suffix.indexOf(QLatin1Char('.')); // it can be like ".tar.xz"
                 if(left != -1 && suffix.size() - left > 1) {
                     return suffix.right(suffix.size() - left - 1);
@@ -920,9 +928,9 @@ void FileDialog::onFileInfoJobFinished() {
                     break;
                 }
             }
-            else if(file->isDir() || file->isShortcut()) {
+            else if(file->isDir() || (file->isShortcut() && !file->isDesktopEntry())) {
                 // we're selecting files, but the selected file path refers to a dir or shortcut (such as computer:///)
-                error = tr("\"%1\" is not a file").arg(QString::fromUtf8(path.displayName().get()));;
+                error = tr("\"%1\" is not a file").arg(QString::fromUtf8(path.displayName().get()));
                 break;
             }
         }
@@ -1109,7 +1117,7 @@ void FileDialog::setMimeTypeFilters(const QStringList& filters) {
                 nameFilter += suffix;
                 nameFilter += QLatin1Char(' ');
             }
-            nameFilter[nameFilter.length() - 1] = ')';
+            nameFilter[nameFilter.length() - 1] = QLatin1Char(')');
         }
         nameFilters << nameFilter;
     }
