@@ -56,6 +56,7 @@ FileMenu::FileMenu(Fm::FileInfoList files, std::shared_ptr<const Fm::FileInfo> i
     openAction_ = nullptr;
     openWithMenuAction_ = nullptr;
     openWithAction_ = nullptr;
+    createAction_ = nullptr;
     separator1_ = nullptr;
     cutAction_ = nullptr;
     copyAction_ = nullptr;
@@ -81,7 +82,7 @@ FileMenu::FileMenu(Fm::FileInfoList files, std::shared_ptr<const Fm::FileInfo> i
     // check if the files are all in the trash can
     allTrash_ =  sameFilesystem_ && path.hasUriScheme("trash");
 
-    openAction_ = new QAction(QIcon::fromTheme("document-open"), tr("Open"), this);
+    openAction_ = new QAction(QIcon::fromTheme(QStringLiteral("document-open")), tr("Open"), this);
     connect(openAction_, &QAction::triggered, this, &FileMenu::onOpenTriggered);
     addAction(openAction_);
 
@@ -112,6 +113,27 @@ FileMenu::FileMenu(Fm::FileInfoList files, std::shared_ptr<const Fm::FileInfo> i
             g_list_free(apps);
         }
     }
+    else {
+        // add a menu-item for opening a mixed selection of files with their default apps
+        auto a = menu->addAction(tr("Default Applications"));
+        connect(a, &QAction::triggered, this, [this] {
+            if(files_.size() > 20) {
+                QMessageBox::StandardButton r = QMessageBox::question(
+                                                parentWidget() ? parentWidget()->window()
+                                                               : nullptr,
+                                                tr("Many files"),
+                                                tr("Do you want to open these %1 files?",
+                                                   nullptr,
+                                                   files_.size()).arg(files_.size()),
+                                                QMessageBox::Yes | QMessageBox::No,
+                                                QMessageBox::No);
+                if(r == QMessageBox::No) {
+                    return;
+                }
+            }
+            fileLauncher_->launchFiles(nullptr, files_);
+        });
+    }
     menu->addSeparator();
     openWithAction_ = new QAction(tr("Other Applications"), this);
     connect(openWithAction_, &QAction::triggered, this, &FileMenu::onOpenWithTriggered);
@@ -119,12 +141,13 @@ FileMenu::FileMenu(Fm::FileInfoList files, std::shared_ptr<const Fm::FileInfo> i
 
     separator1_ = addSeparator();
 
-    createAction_ = new QAction(tr("Create &New"), this);
-    Fm::FilePath dirPath = files_.size() == 1 && info_->isDir() ? path : cwd_;
-    createAction_->setMenu(new CreateNewMenu(parent, dirPath, this));
-    addAction(createAction_);
-
-    separator2_ = addSeparator();
+    if(!allTrash_) {
+        createAction_ = new QAction(tr("Create &New"), this);
+        Fm::FilePath dirPath = files_.size() == 1 && info_->isDir() ? path : cwd_;
+        createAction_->setMenu(new CreateNewMenu(parent, dirPath, this));
+        addAction(createAction_);
+        separator2_ = addSeparator();
+    }
 
     if(allTrash_) { // all selected files are in trash:///
         bool can_restore = true;
@@ -141,22 +164,26 @@ FileMenu::FileMenu(Fm::FileInfoList files, std::shared_ptr<const Fm::FileInfo> i
             unTrashAction_ = new QAction(tr("&Restore"), this);
             connect(unTrashAction_, &QAction::triggered, this, &FileMenu::onUnTrashTriggered);
             addAction(unTrashAction_);
+
+            deleteAction_ = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), tr("&Delete"), this);
+            connect(deleteAction_, &QAction::triggered, this, &FileMenu::onDeleteTriggered);
+            addAction(deleteAction_);
         }
     }
     else { // ordinary files
-        cutAction_ = new QAction(QIcon::fromTheme("edit-cut"), tr("Cut"), this);
+        cutAction_ = new QAction(QIcon::fromTheme(QStringLiteral("edit-cut")), tr("Cut"), this);
         connect(cutAction_, &QAction::triggered, this, &FileMenu::onCutTriggered);
         addAction(cutAction_);
 
-        copyAction_ = new QAction(QIcon::fromTheme("edit-copy"), tr("Copy"), this);
+        copyAction_ = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), tr("Copy"), this);
         connect(copyAction_, &QAction::triggered, this, &FileMenu::onCopyTriggered);
         addAction(copyAction_);
 
-        pasteAction_ = new QAction(QIcon::fromTheme("edit-paste"), tr("Paste"), this);
+        pasteAction_ = new QAction(QIcon::fromTheme(QStringLiteral("edit-paste")), tr("Paste"), this);
         connect(pasteAction_, &QAction::triggered, this, &FileMenu::onPasteTriggered);
         addAction(pasteAction_);
 
-        deleteAction_ = new QAction(QIcon::fromTheme("user-trash"), tr("&Move to Trash"), this);
+        deleteAction_ = new QAction(QIcon::fromTheme(QStringLiteral("user-trash")), tr("&Move to Trash"), this);
         connect(deleteAction_, &QAction::triggered, this, &FileMenu::onDeleteTriggered);
         addAction(deleteAction_);
 
@@ -189,25 +216,30 @@ FileMenu::FileMenu(Fm::FileInfoList files, std::shared_ptr<const Fm::FileInfo> i
         if(!(sameType_ && info_->isDir()
              && (files_.size() > 1 ? isWritableDir : info_->isWritable()))) {
             pasteAction_->setEnabled(false);
+            if(createAction_) {
+                createAction_->setEnabled(false);
+            }
         }
     }
 
     // DES-EMA custom actions integration
     // FIXME: port these parts to Fm API
     auto custom_actions = FileActionItem::get_actions_for_files(files_);
+    bool firstAction = true;
     for(auto& item: custom_actions) {
         if(item && !(item->get_target() & FILE_ACTION_TARGET_CONTEXT)) {
             continue;  // this item is not for context menu
         }
-        if(item == custom_actions.front() && !item->is_action()) {
+        if(firstAction) {
             addSeparator(); // before all custom actions
+            firstAction = false;
         }
         addCustomActionItem(this, item);
     }
 
     // archiver integration
     // FIXME: we need to modify upstream libfm to include some Qt-based archiver programs.
-    if(!allVirtual_) {
+    if(!allVirtual_ && !allTrash_) {
         auto archiver = Archiver::defaultArchiver();
         if(archiver) {
             if(sameType_ && archiver->isMimeTypeSupported(mime_type->name())) {
@@ -238,7 +270,7 @@ FileMenu::FileMenu(Fm::FileInfoList files, std::shared_ptr<const Fm::FileInfo> i
 
     separator3_ = addSeparator();
 
-    propertiesAction_ = new QAction(QIcon::fromTheme("document-properties"), tr("Properties"), this);
+    propertiesAction_ = new QAction(QIcon::fromTheme(QStringLiteral("document-properties")), tr("Properties"), this);
     connect(propertiesAction_, &QAction::triggered, this, &FileMenu::onFilePropertiesTriggered);
     addAction(propertiesAction_);
 }
@@ -322,8 +354,7 @@ void FileMenu::openFilesWithApp(GAppInfo* app) {
     }
     uris = g_list_reverse(uris); // respect the original order
     fm_app_info_launch_uris(app, uris, nullptr, nullptr);
-    g_list_foreach(uris, (GFunc)g_free, nullptr);
-    g_list_free(uris);
+    g_list_free_full(uris, g_free);
 }
 
 void FileMenu::onApplicationTriggered() {
@@ -339,7 +370,7 @@ void FileMenu::onCustomActionTrigerred() {
     CStrPtr output;
     item->launch(nullptr, files_, output);
     if(output) {
-        QMessageBox::information(this, tr("Output"), output.get());
+        QMessageBox::information(this, tr("Output"), QString::fromUtf8(output.get()));
     }
 }
 
@@ -363,7 +394,7 @@ void FileMenu::onCutTriggered() {
 
 void FileMenu::onDeleteTriggered() {
     auto paths = files_.paths();
-    if(useTrash_) {
+    if(useTrash_ && !info_->path().hasUriScheme("trash")) {
         FileOperation::trashFiles(paths, confirmTrash_, parentWidget());
     }
     else {
@@ -403,9 +434,9 @@ void FileMenu::onRenameTriggered() {
 void FileMenu::setUseTrash(bool trash) {
     if(useTrash_ != trash) {
         useTrash_ = trash;
-        if(deleteAction_) {
+        if(deleteAction_ && !info_->path().hasUriScheme("trash")) {
             deleteAction_->setText(useTrash_ ? tr("&Move to Trash") : tr("&Delete"));
-            deleteAction_->setIcon(useTrash_ ? QIcon::fromTheme("user-trash") : QIcon::fromTheme("edit-delete"));
+            deleteAction_->setIcon(useTrash_ ? QIcon::fromTheme(QStringLiteral("user-trash")) : QIcon::fromTheme(QStringLiteral("edit-delete")));
         }
     }
 }
