@@ -301,10 +301,28 @@ void FilePropsDialog::initGeneralPage() {
         else {
             ui->location->clear();
         }
-        auto mtime = QDateTime::fromMSecsSinceEpoch(fileInfo->mtime() * 1000);
-        ui->lastModified->setText(mtime.toString(Qt::SystemLocaleShortDate));
-        auto atime = QDateTime::fromMSecsSinceEpoch(fileInfo->atime() * 1000);
-        ui->lastAccessed->setText(atime.toString(Qt::SystemLocaleShortDate));
+        // times
+        if(fileInfo->mtime() > 0) {
+            auto mtime = QDateTime::fromMSecsSinceEpoch(fileInfo->mtime() * 1000);
+            ui->lastModified->setText(mtime.toString(Qt::SystemLocaleShortDate));
+        }
+        else {
+            ui->lastModified->setText(tr("N/A"));
+        }
+        if(fileInfo->atime() > 0) {
+            auto atime = QDateTime::fromMSecsSinceEpoch(fileInfo->atime() * 1000);
+            ui->lastAccessed->setText(atime.toString(Qt::SystemLocaleShortDate));
+        }
+        else {
+            ui->lastAccessed->setText(tr("N/A"));
+        }
+        if(fileInfo->crtime() > 0) {
+            auto crtime = QDateTime::fromMSecsSinceEpoch(fileInfo->crtime() * 1000);
+            ui->created->setText(crtime.toString(Qt::SystemLocaleShortDate));
+        }
+        else {
+            ui->created->setText(tr("N/A"));
+        }
     }
     else {
         ui->fileName->setText(tr("Multiple Files"));
@@ -421,7 +439,11 @@ void FilePropsDialog::onIconButtonclicked() {
                                                           iconDir,
                                                           tr("Images (*.png *.xpm *.svg *.svgz )"));
     if(!iconPath.isEmpty()) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+        QStringList parts = iconPath.split(QStringLiteral("/"), Qt::SkipEmptyParts);
+#else
         QStringList parts = iconPath.split(QStringLiteral("/"), QString::SkipEmptyParts);
+#endif
         if(!parts.isEmpty()) {
             QString iconName = parts.at(parts.count() - 1);
             int ln = iconName.lastIndexOf(QLatin1String("."));
@@ -589,9 +611,10 @@ void FilePropsDialog::initOwner() {
             ui->ownerGroup->setText(gidToName(gid));
         }
 
-        if(geteuid() != 0) { // on local filesystems, only root can do chown.
+        uid_t userId = geteuid();
+        if(userId != 0) { // on local filesystems, only root can do chown.
             ui->owner->setEnabled(false);
-            ui->ownerGroup->setEnabled(false);
+            ui->ownerGroup->setEnabled(userId == uid);
         }
     }
 }
