@@ -32,16 +32,17 @@
 #include <QLineEdit>
 #include <QTextEdit>
 #include <QTimer>
+#include <QStandardPaths>
 #include <QDebug>
 
 namespace Fm {
 
 FolderItemDelegate::FolderItemDelegate(QAbstractItemView* view, QObject* parent):
     QStyledItemDelegate(parent ? parent : view),
-    symlinkIcon_(QIcon::fromTheme("emblem-symbolic-link")),
-    untrustedIcon_(QIcon::fromTheme("emblem-important")),
-    addIcon_(QIcon::fromTheme("list-add")),
-    removeIcon_(QIcon::fromTheme("list-remove")),
+    symlinkIcon_(QIcon::fromTheme(QStringLiteral("emblem-symbolic-link"))),
+    untrustedIcon_(QIcon::fromTheme(QStringLiteral("emblem-important"))),
+    addIcon_(QIcon::fromTheme(QStringLiteral("list-add"))),
+    removeIcon_(QIcon::fromTheme(QStringLiteral("list-remove"))),
     fileInfoRole_(Fm::FolderModel::FileInfoRole),
     iconInfoRole_(-1),
     margins_(QSize(3, 3)),
@@ -129,8 +130,14 @@ void FolderItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& op
 
     bool isSymlink = file && file->isSymlink();
     bool isCut = index.data(FolderModel::FileIsCutRole).toBool();
-    // for practical reasons, an emblem is added only to an untrusted, deletable desktop file
+    // an emblem is added only to an untrusted, deletable desktop file that isn't inside applications directory
     bool untrusted = file && !file->isTrustable() && file->isDesktopEntry() && file->isDeletable();
+    if(untrusted) {
+        auto parentDir = QString::fromUtf8((file->dirPath().toString().get()));
+        if(QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation).contains(parentDir)) {
+            untrusted = false;
+        }
+    }
     // vertical layout (icon mode, thumbnail mode)
     if(option.decorationPosition == QStyleOptionViewItem::Top ||
             option.decorationPosition == QStyleOptionViewItem::Bottom) {
@@ -141,63 +148,67 @@ void FolderItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& op
         opt.displayAlignment = Qt::AlignTop | Qt::AlignHCenter;
 
         // draw the icon
-        QIcon::Mode iconMode = shadowIcon ? QIcon::Disabled : iconModeFromState(opt.state);
+        QIcon::Mode iconMode = shadowIcon ? QIcon::Disabled
+                                          // in the icon and thumbnail modes, we select text, not icon
+                                          : iconModeFromState(opt.state & ~QStyle::State_Selected);
         QPoint iconPos(opt.rect.x() + (opt.rect.width() - option.decorationSize.width()) / 2, opt.rect.y() + margins_.height());
-        QPixmap pixmap = opt.icon.pixmap(option.decorationSize, iconMode);
-        // in case the pixmap is smaller than the requested size
-        QSize margin = ((option.decorationSize - pixmap.size()) / 2).expandedTo(QSize(0, 0));
+        QRect iconRect(iconPos, option.decorationSize);
         if(isCut) {
             painter->save();
             painter->setOpacity(0.45);
         }
-        painter->drawPixmap(iconPos + QPoint(margin.width(), margin.height()), pixmap);
+        opt.icon.paint(painter, iconRect, Qt::AlignCenter, iconMode);
         if(isCut) {
             painter->restore();
         }
 
         // draw some emblems for the item if needed
+        iconRect.setSize(option.decorationSize / 2);
         if(isSymlink) {
             // draw the emblem for symlinks
-            painter->drawPixmap(iconPos, symlinkIcon_.pixmap(option.decorationSize / 2, iconMode));
+            symlinkIcon_.paint(painter, iconRect, Qt::AlignCenter, iconMode);
         }
 
         if(untrusted) {
             // emblem for untrusted, deletable desktop files
-            painter->drawPixmap(iconPos.x(), opt.rect.y() + option.decorationSize.height() / 2, untrustedIcon_.pixmap(option.decorationSize / 2, iconMode));
+            untrustedIcon_.paint(painter, iconRect.translated(0, option.decorationSize.height() / 2), Qt::AlignCenter, iconMode);
         }
 
         // draw other emblems if there's any
         if(!emblems.empty()) {
             // FIXME: we only support one emblem now
-            QPoint emblemPos(opt.rect.x() + opt.rect.width() / 2, opt.rect.y() + option.decorationSize.height() / 2);
             QIcon emblem = emblems.front()->qicon();
-            painter->drawPixmap(emblemPos, emblem.pixmap(option.decorationSize / 2, iconMode));
+            emblem.paint(painter, iconRect.translated(option.decorationSize.width() / 2, option.decorationSize.height() / 2), Qt::AlignCenter, iconMode);
         }
 
         // Draw select/deselect icons outside the main icon but near its top left corner,
         // with its 1/3 size and only if the icon size isn't smaller than 48 px
         // (otherwise, the user could not click on them easily).
-        if(option.decorationSize.width() >= 48 && opt.state & QStyle::State_MouseOver) {
+        const QAbstractItemView* iv = qobject_cast<const QAbstractItemView*>(opt.widget);
+        if(iv != nullptr
+           // only for the extended and multiple selection modes
+           && (iv->selectionMode() == QAbstractItemView::ExtendedSelection
+               || iv->selectionMode() == QAbstractItemView::MultiSelection)
+           && option.decorationSize.width() >= 48 && (opt.state & QStyle::State_MouseOver)) {
             int s = option.decorationSize.width() / 3;
             bool cursorOnSelectionCorner = false;
             iconPos = QPoint(qMax(opt.rect.x(), iconPos.x() - s),
                              qMax(opt.rect.y(), iconPos.y() - s));
-            if(const QAbstractItemView* iv = qobject_cast<const QAbstractItemView*>(opt.widget)) {
-                QPoint curPos = iv->viewport()->mapFromGlobal(QCursor::pos());
-                if(curPos.x() >= iconPos.x() && curPos.x() <= iconPos.x() + s
-                   && curPos.y() >= iconPos.y() && curPos.y() <= iconPos.y() + s) {
-                    cursorOnSelectionCorner = true;
-                }
+            QPoint curPos = iv->viewport()->mapFromGlobal(QCursor::pos());
+            if(curPos.x() >= iconPos.x() && curPos.x() <= iconPos.x() + s
+               && curPos.y() >= iconPos.y() && curPos.y() <= iconPos.y() + s) {
+                cursorOnSelectionCorner = true;
             }
             if(!cursorOnSelectionCorner) { // make it translucent when not under the cursor
                 painter->save();
                 painter->setOpacity(0.6);
             }
+            iconRect = QRect(iconPos, QSize(s, s));
             if(opt.state & QStyle::State_Selected) {
-                painter->drawPixmap(iconPos, removeIcon_.pixmap(QSize(s, s), QIcon::Normal));
+                removeIcon_.paint(painter, iconRect, Qt::AlignCenter, QIcon::Normal);
             }
             else {
-                painter->drawPixmap(iconPos, addIcon_.pixmap(QSize(s, s), QIcon::Normal));
+                addIcon_.paint(painter, iconRect, Qt::AlignCenter, QIcon::Normal);
             }
             if(!cursorOnSelectionCorner) {
                 painter->restore();
@@ -252,19 +263,18 @@ void FolderItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& op
         }
 
         // draw some emblems for the item if needed
+        QRect iconRect = style->subElementRect(QStyle::SE_ItemViewItemDecoration, &opt, widget);
+        iconRect.setSize(option.decorationSize / 2);
         if(isSymlink) {
-            QPoint iconPos(opt.rect.x(), opt.rect.y() + (opt.rect.height() - option.decorationSize.height()) / 2);
-            painter->drawPixmap(iconPos, symlinkIcon_.pixmap(option.decorationSize / 2, iconMode));
+            symlinkIcon_.paint(painter, iconRect, Qt::AlignCenter, iconMode);
         }
         if(untrusted) {
-            QPoint iconPos(opt.rect.x(), opt.rect.y() + opt.rect.height() / 2);
-            painter->drawPixmap(iconPos, untrustedIcon_.pixmap(option.decorationSize / 2, iconMode));
+            untrustedIcon_.paint(painter, iconRect.translated(0, option.decorationSize.height() / 2), Qt::AlignCenter, iconMode);
         }
         if(!emblems.empty()) {
             // FIXME: we only support one emblem now
-            QPoint iconPos(opt.rect.x() + option.decorationSize.width() / 2, opt.rect.y() + opt.rect.height() / 2);
             QIcon emblem = emblems.front()->qicon();
-            painter->drawPixmap(iconPos, emblem.pixmap(option.decorationSize / 2, iconMode));
+            emblem.paint(painter, iconRect.translated(option.decorationSize.width() / 2, option.decorationSize.height() / 2), Qt::AlignCenter, iconMode);
         }
     }
 }
@@ -312,7 +322,12 @@ void FolderItemDelegate::drawText(QPainter* painter, QStyleOptionViewItem& opt,
         ++ visibleLines;
     }
     layout.endLayout();
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+    width = qMax(width, static_cast<qreal>(opt.fontMetrics.horizontalAdvance(elidedText)));
+#else
     width = qMax(width, (qreal)opt.fontMetrics.width(elidedText));
+#endif
 
     // draw background for selected item
     QRectF boundRect = layout.boundingRect();
@@ -455,24 +470,24 @@ void FolderItemDelegate::setEditorData(QWidget* editor, const QModelIndex& index
         // select text appropriately
         QTextCursor cur = textEdit->textCursor();
         int end;
-        if (index.data(Fm::FolderModel::FileIsDirRole).toBool() || !currentName.contains(".")) {
+        if (index.data(Fm::FolderModel::FileIsDirRole).toBool() || !currentName.contains(QLatin1String("."))) {
             end = currentName.size();
         }
         else {
-            end = currentName.lastIndexOf(".");
+            end = currentName.lastIndexOf(QLatin1String("."));
         }
         cur.setPosition(end, QTextCursor::KeepAnchor);
         textEdit->setTextCursor(cur);
     }
     else if (QLineEdit* lineEdit = qobject_cast<QLineEdit*>(editor)) {
         lineEdit->setText(currentName);
-        if (!index.data(Fm::FolderModel::FileIsDirRole).toBool() && currentName.contains("."))
+        if (!index.data(Fm::FolderModel::FileIsDirRole).toBool() && currentName.contains(QLatin1String(".")))
         {
             /* Qt will call QLineEdit::selectAll() after calling setEditorData() in
                qabstractitemview.cpp -> QAbstractItemViewPrivate::editor(). Therefore,
                we cannot select a part of the text in the usual way here.  */
-            QTimer::singleShot(0, [lineEdit]() {
-                int length = lineEdit->text().lastIndexOf(".");
+            QTimer::singleShot(0, lineEdit, [lineEdit]() {
+                int length = lineEdit->text().lastIndexOf(QLatin1String("."));
                 lineEdit->setSelection(0, length);
             });
         }
