@@ -885,7 +885,11 @@ void FolderView::setCustomColumnWidths(const QList<int> &widths) {
 
 void FolderView::setHiddenColumns(const QList<int> &columns) {
     hiddenColumns_.clear();
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+    hiddenColumns_ = QSet<int>(columns.begin(), columns.end());
+#else
     hiddenColumns_ = columns.toSet();
+#endif
     if(mode == DetailedListMode) {
         if(FolderViewTreeView* treeView = static_cast<FolderViewTreeView*>(view)) {
             treeView->setHiddenColumns(hiddenColumns_);
@@ -1376,9 +1380,6 @@ void FolderView::selectFiles(const Fm::FileInfoList& files, bool add) {
     if(!model_ || files.empty()) {
         return;
     }
-    if(!add) {
-        selectionModel()->clear();
-    }
     QModelIndex index, firstIndex;
     int count = model_->rowCount();
     Fm::FileInfoList list = files;
@@ -1396,9 +1397,14 @@ void FolderView::selectFiles(const Fm::FileInfoList& files, bool add) {
         for(auto it = list.cbegin(); it != list.cend(); ++it) {
             auto& item = *it;
             if(item == info) {
-                selectionModel()->select(index, flags);
-                if (!firstIndex.isValid()) {
-                    firstIndex = index;
+                if(model_->showHidden() || !info->isHidden()) {
+                    if (!firstIndex.isValid()) {
+                        firstIndex = index;
+                        if(!add) {
+                            selectionModel()->clear();
+                        }
+                    }
+                    selectionModel()->select(index, flags);
                 }
                 list.erase(it);
                 break;
@@ -1600,13 +1606,15 @@ bool FolderView::eventFilter(QObject* watched, QEvent* event) {
                                                         : view->verticalScrollBar());
                 if(sbar != nullptr) {
                     QWheelEvent *we = static_cast<QWheelEvent*>(event);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,12,0))
+#if (QT_VERSION < QT_VERSION_CHECK(5,14,0))
                     QWheelEvent e(we->posF(),
                                   we->globalPosF(),
                                   we->pixelDelta(),
-#if (QT_VERSION < QT_VERSION_CHECK(5,14,0))
                                   QPoint (0, we->angleDelta().y() / QApplication::wheelScrollLines()),
 #else
+                    QWheelEvent e(we->position(),
+                                  we->globalPosition(),
+                                  we->pixelDelta(),
                                   // the problem with horizontal wheel scrolling from inside view is fixed in Qt 5.14
                                   mode == CompactMode
                                     ? QPoint (we->angleDelta().y() / QApplication::wheelScrollLines(), 0)
@@ -1617,14 +1625,6 @@ bool FolderView::eventFilter(QObject* watched, QEvent* event) {
                                   we->phase(),
                                   false,
                                   we->source());
-#else
-                    QWheelEvent e(we->posF(),
-                                  we->globalPosF(),
-                                  we->angleDelta().y() / QApplication::wheelScrollLines(),
-                                  we->buttons(),
-                                  Qt::NoModifier,
-                                  Qt::Vertical);
-#endif
                     QApplication::sendEvent(sbar, &e);
                     return true;
                 }
